@@ -1,7 +1,7 @@
 use ruma::events::*;
 pub use ruma::{
-    api::client::sync::sync_events::v3::Response, identifiers::RoomName, EventId, RoomAliasId,
-    RoomId, ServerName, UserId,
+    api::client::sync::sync_events::v3::Response, OwnedEventId, OwnedRoomAliasId, OwnedRoomId,
+    OwnedRoomName, OwnedServerName, OwnedUserId, RoomAliasId, RoomId, RoomName, ServerName, UserId,
 };
 use serde::{Deserialize, Serialize};
 //use serde_json::{json, Value};
@@ -13,14 +13,14 @@ const TIMEOUT: Duration = Duration::from_secs(3);
 #[derive(Clone, Debug, Serialize, Deserialize, Default)]
 pub struct StorageData {
     pub auth_token: String,
-    pub room_to_aliases: BTreeMap<Box<RoomId>, Vec<Box<RoomAliasId>>>,
-    pub alias_to_room: BTreeMap<Box<RoomAliasId>, Box<RoomId>>,
-    pub joined_rooms: Vec<Box<RoomId>>,
-    pub room_id_to_cananoical_alias: BTreeMap<Box<RoomId>, Box<RoomAliasId>>,
-    pub room_to_name: BTreeMap<Box<RoomId>, Box<RoomName>>,
-    pub room_to_direct_name: BTreeMap<Box<RoomId>, String>,
-    pub recent_event_ids: Vec<Box<EventId>>,
-    pub last_sent_messages: Vec<(Box<RoomId>, String)>,
+    pub room_to_aliases: BTreeMap<OwnedRoomId, Vec<OwnedRoomAliasId>>,
+    pub alias_to_room: BTreeMap<OwnedRoomAliasId, OwnedRoomId>,
+    pub joined_rooms: Vec<OwnedRoomId>,
+    pub room_id_to_cananoical_alias: BTreeMap<OwnedRoomId, OwnedRoomAliasId>,
+    pub room_to_name: BTreeMap<OwnedRoomId, OwnedRoomName>,
+    pub room_to_direct_name: BTreeMap<OwnedRoomId, String>,
+    pub recent_event_ids: Vec<OwnedEventId>,
+    pub last_sent_messages: Vec<(OwnedRoomId, String)>,
 }
 /*
 #[derive(Clone, Debug, Serialize, Deserialize, Default)]
@@ -67,7 +67,7 @@ pub struct Response {
 #[derive(Debug, Clone)]
 pub struct Client {
     client: ruma::Client<ruma::client::http_client::Reqwest>,
-    pub me: Box<UserId>,
+    pub me: OwnedUserId,
     since: Option<String>,
     host: String,
     pub data: StorageData,
@@ -200,11 +200,11 @@ impl Client {
             return Err(val);
         }
         self.data.auth_token = val["access_token"].as_str().unwrap().to_string();
-        self.me = UserId::try_from(val["user_id"].as_str().unwrap()).unwrap();
+        self.me = OwnedUserId::try_from(val["user_id"].as_str().unwrap()).unwrap();
         Ok(())
     }
     */
-    pub fn get_me(&self) -> Box<UserId> {
+    pub fn get_me(&self) -> OwnedUserId {
         self.me.clone()
     }
     /*
@@ -324,7 +324,7 @@ impl Client {
         //println!("{:#?}", resp);
         resp
     }
-    pub fn join_room_id(&self, room_id: ruma::RoomId) -> Value {
+    pub fn join_room_id(&self, room_id: OwnedRoomId) -> Value {
         let rid = room_id.to_string();
         let room = urlencoding::encode(rid.as_str());
         let content = json!({});
@@ -336,7 +336,7 @@ impl Client {
     */
     pub async fn join_room_id(
         &self,
-        room_id: Box<ruma::RoomId>,
+        room_id: OwnedRoomId,
     ) -> ruma::api::client::membership::join_room_by_id::v3::Response {
         self.client
             .send_request(
@@ -439,10 +439,10 @@ impl Client {
             .into_json()
             .unwrap();
         let room_id =
-            ruma::RoomId::try_from(this_room_id_val["room_id"].as_str().unwrap()).unwrap();
+            OwnedRoomId::try_from(this_room_id_val["room_id"].as_str().unwrap()).unwrap();
         self.join_room_id(room_id);
     }
-    pub fn leave_room_id(&mut self, room_id: Box<RoomId>) -> Value {
+    pub fn leave_room_id(&mut self, room_id: OwnedRoomId) -> Value {
         let rid = room_id.to_string();
         let room = urlencoding::encode(rid.as_str());
         let content = json!({});
@@ -458,7 +458,7 @@ impl Client {
     */
     pub async fn leave_room_id(
         &mut self,
-        room_id: Box<RoomId>,
+        room_id: OwnedRoomId,
     ) -> ruma::api::client::membership::leave_room::v3::Response {
         let resp = self
             .client
@@ -472,7 +472,7 @@ impl Client {
         resp
     }
     /*
-    pub fn room_id_from_alias(&self, alias: impl Into<String>) -> Box<RoomId> {
+    pub fn room_id_from_alias(&self, alias: impl Into<String>) -> OwnedRoomId {
         let room_alias = alias.into();
         let this_room_id_val: Value = self
             .get(
@@ -487,10 +487,10 @@ impl Client {
             .unwrap()
             .into_json()
             .unwrap();
-        ruma::RoomId::try_from(this_room_id_val["room_id"].as_str().unwrap()).unwrap()
+        OwnedRoomId::try_from(this_room_id_val["room_id"].as_str().unwrap()).unwrap()
     }
     */
-    pub async fn room_id_from_alias(&self, alias: impl Into<String>) -> Box<RoomId> {
+    pub async fn room_id_from_alias(&self, alias: impl Into<String>) -> OwnedRoomId {
         let room_alias_string = alias.into();
         let room_alias = RoomAliasId::parse(room_alias_string.as_str()).unwrap();
         self.client
@@ -502,7 +502,7 @@ impl Client {
             .room_id
     }
     /*
-    pub fn send_message(&mut self, room_id: Box<RoomId>, message: impl Into<String>) {
+    pub fn send_message(&mut self, room_id: OwnedRoomId, message: impl Into<String>) {
         let msg = message.into();
         let txid = Uuid::new_v4()
             .to_simple()
@@ -519,7 +519,7 @@ impl Client {
     */
     pub async fn send_message(
         &mut self,
-        room_id: Box<RoomId>,
+        room_id: OwnedRoomId,
         message: impl Into<String>,
     ) -> ruma::api::client::message::send_message_event::v3::Response {
         let msg = message.into();
@@ -550,8 +550,9 @@ impl Client {
             let mut is_direct = false;
             for event in joined_room.state.events.clone() {
                 if let Ok(ev) = event.deserialize() {
-                    if let ruma::events::AnySyncStateEvent::RoomAliases(room_aliases_event) =
-                        ev.clone()
+                    if let ruma::events::AnySyncStateEvent::RoomAliases(SyncStateEvent::Original(
+                        room_aliases_event,
+                    )) = ev.clone()
                     {
                         let aliases = room_aliases_event.content.aliases;
                         for alias in aliases {
@@ -578,12 +579,17 @@ impl Client {
                             }
                         }
                     }
-                    if let ruma::events::AnySyncStateEvent::RoomName(room_name_event) = ev.clone() {
+                    if let ruma::events::AnySyncStateEvent::RoomName(SyncStateEvent::Original(
+                        room_name_event,
+                    )) = ev.clone()
+                    {
                         if let Some(room_name) = room_name_event.content.name {
-                            self.data.room_to_name.insert(room_id.clone(), room_name);
+                            self.data
+                                .room_to_name
+                                .insert(room_id.clone(), room_name.into());
                         }
                     } else if let ruma::events::AnySyncStateEvent::RoomCanonicalAlias(
-                        room_canonical_alias_event,
+                        SyncStateEvent::Original(room_canonical_alias_event),
                     ) = ev.clone()
                     {
                         if let Some(alias) = room_canonical_alias_event.content.alias {
@@ -591,8 +597,9 @@ impl Client {
                                 .room_id_to_cananoical_alias
                                 .insert(room_id.clone(), alias);
                         }
-                    } else if let ruma::events::AnySyncStateEvent::RoomMember(room_member_event) =
-                        ev.clone()
+                    } else if let ruma::events::AnySyncStateEvent::RoomMember(
+                        SyncStateEvent::Original(room_member_event),
+                    ) = ev.clone()
                     {
                         if let Some(display_name) = room_member_event.content.displayname {
                             room_members.push(display_name);
@@ -612,7 +619,7 @@ impl Client {
                     .insert(room_id.clone(), room_members[0].clone());
             }
             for message_info in joined_room.timeline.events.iter().filter_map(|m| {
-                if let Ok(ruma::events::AnySyncRoomEvent::Message(message_event)) =
+                if let Ok(ruma::events::AnySyncRoomEvent::MessageLike(message_event)) =
                     m.deserialize_as()
                 {
                     let msg_event_id = Box::new(message_event.event_id().to_owned());
@@ -625,23 +632,29 @@ impl Client {
                     if self.data.recent_event_ids.len() > 500 {
                         self.data.recent_event_ids.remove(0);
                     }
-                    if let ruma::events::AnySyncMessageEvent::RoomMessage(room_message) =
-                        message_event
+                    if let AnySyncMessageLikeEvent::RoomMessage(SyncMessageLikeEvent::Original(
+                        room_message,
+                    )) = message_event
                     {
                         let sender = room_message.sender;
                         let message: String;
-                        let is_emote: bool;
+                        let mut is_emote: bool = false;
                         if let room::message::MessageType::Text(text_message_event_content) =
                             room_message.content.msgtype
                         {
                             message = text_message_event_content.body;
-                            is_emote = false;
+                            //is_emote = false;
                         } else if let room::message::MessageType::Emote(
                             emote_message_event_content,
                         ) = room_message.content.msgtype
                         {
                             message = emote_message_event_content.body;
                             is_emote = true;
+                        } else if let room::message::MessageType::Notice(
+                            notice_message_event_content,
+                        ) = room_message.content.msgtype
+                        {
+                            message = notice_message_event_content.body;
                         } else {
                             return None;
                         }
@@ -671,8 +684,8 @@ impl Client {
 }
 
 pub struct MessageInfo {
-    pub room_id: Box<RoomId>,
-    pub sender: Box<UserId>,
+    pub room_id: OwnedRoomId,
+    pub sender: OwnedUserId,
     pub message: String,
     pub is_emote: bool,
 }
